/* Declinazione di responsabilità. 
I file rilasciati in formato testo sono provvisti anche dei programmi di importazione per STATA, SAS e R. 
L'Istat non garantisce che le funzioni contenute nei suddetti programmi siano esenti da errore e non si assume alcuna responsabilità sull’output ottenuto dal loro utilizzo.                 */
%macro grabpath;
%qsubstr(%sysget(SAS_EXECFILEPATH),1,%length(%sysget(SAS_EXECFILEPATH))-%length(%sysget(SAS_EXECFILEname)))
%mend grabpath;
%let path = %grabpath;
%let nomeFile =ISTAT_MFR_VV_Microdati_2020_Escursioni_ESEMPIO_STRUTTURA_FILE.txt;
LIBNAME ISTAT "&path";
DATA ISTAT.VV_A2020_Escursioni;

INFILE "&path&nomeFile" DLM='09'x  LRECL=32767 TRUNCOVER FIRSTOBS=2 IGNOREDOSEOF;
INPUT 
tr : $2.   /*  tipo record */
mese : $2.   /*  mese di riferimento dei dati */
annrif : $4.   /*  anno di riferimento dei dati */
progind : $5.   /*  numero d'ordine progressivo dell'individuo nell'anno */
sesso : $1.   /*  sesso */
eta5 : $2.   /*  classi di eta' in anni compiuti */
staciv : $1.   /*  stato civile */
reg : $3.   /*  regione di residenza */
rip : $1.   /*  ripartizione geografica di residenza */
istr : $2.   /*  titolo di studio piu' alto conseguito */
condogg : $2.   /*  condizione professionale oggettiva */
posiz : $2.   /*  posizione nella professione */
ateco10 : $2.   /*  settore di attivita' economica */
cond : $2.   /*  condizione professionale soggettiva (autodichiarata) */
ORARIO : $1.   /*  tipo di orario di lavoro */
RAPP : $1.   /*  tipo di rapporto di lavoro */
CODPROF : $1.   /*  codifica della professione lavorativa (Grandi gruppi) */
progesc : $2.   /*  Numero progressivo dell'escursione per ciascun individuo */
DEST_EIE : $1.   /*  destinazione principale: italia/estero */
DEST_ERE : $3.   /*  regione italiana o stato estero dell'UE di destinazione principale o macro-area geografica non UE */
DEST_EPR : $3.   /*  provincia italiana di destinazione principale */
MOTESC : $2.   /*  motivo prevalente dell'escursione */
PARTESC : $1.   /*  Filtro: Se hanno partecipato all'escursione altri componenti della famiglia */
NPARTESC : $2.   /*  Numero totale di componenti familiari partecipanti all'escursione */
EMEZZO : $2.   /*  Mezzo principale di trasporto */
W :19.7   /*  coefficiente di riporto per le stime di viaggi, escursioni e individui (turisti e non turisti) nel mese medio del trimestre */
COEV :19.7   /*  coefficiente di riporto per il calcolo dell'ammontare dei viaggi (abituali e non abituali) ed escursioni nel mese, nel trimestre e nell'anno */
TRIM : $2.   /*  trimestre di riferimento dei dati */
DOMINIO : $1.   /*  tipologia socio-demografica del comune di residenza */
;
LABEL 
tr = "tipo record"
mese = "mese di riferimento dei dati"
annrif = "anno di riferimento dei dati"
progind = "numero d'ordine progressivo dell'individuo nell'anno"
sesso = "sesso"
eta5 = "classi di eta' in anni compiuti"
staciv = "stato civile"
reg = "regione di residenza"
rip = "ripartizione geografica di residenza"
istr = "titolo di studio piu' alto conseguito"
condogg = "condizione professionale oggettiva"
posiz = "posizione nella professione"
ateco10 = "settore di attivita' economica"
cond = "condizione professionale soggettiva (autodichiarata)"
ORARIO = "tipo di orario di lavoro"
RAPP = "tipo di rapporto di lavoro"
CODPROF = "codifica della professione lavorativa (Grandi gruppi)"
progesc = "Numero progressivo dell'escursione per ciascun individuo"
DEST_EIE = "destinazione principale: italia/estero"
DEST_ERE = "regione italiana o stato estero dell'UE di destinazione principale o macro-area geografica non UE"
DEST_EPR = "provincia italiana di destinazione principale"
MOTESC = "motivo prevalente dell'escursione"
PARTESC = "Filtro: Se hanno partecipato all'escursione altri componenti della famiglia"
NPARTESC = "Numero totale di componenti familiari partecipanti all'escursione"
EMEZZO = "Mezzo principale di trasporto"
W = "coefficiente di riporto per le stime di viaggi, escursioni e individui (turisti e non turisti) nel mese medio del trimestre"
COEV = "coefficiente di riporto per il calcolo dell'ammontare dei viaggi (abituali e non abituali) ed escursioni nel mese, nel trimestre e nell'anno"
TRIM = "trimestre di riferimento dei dati"
DOMINIO = "tipologia socio-demografica del comune di residenza"
;
RUN;
PROC FORMAT;
VALUE $tr0F /* tr */
"02" = "Record individuale"
"03" = "Record viaggi"
"04" = "Record escursioni"
;
VALUE $ses4F /* sesso */
"1" = "Maschi"
"2" = "Femmine"
;
VALUE $eta5F /* eta5 */
"01" = "<=5 anni"
"02" = "6-14 anni"
"03" = "15-17 anni"
"04" = "18-24 anni"
"05" = "25-29 anni"
"06" = "30-34 anni"
"07" = "35-39 anni"
"08" = "40-44 anni"
"09" = "45-49 anni"
"10" = "50-54 anni"
"11" = "55-59 anni"
"12" = "60-64 anni"
"13" = "65-69 anni"
"14" = "70-74 anni"
"15" = ">=75 anni"
;
VALUE $sta6F /* staciv */
"1" = "Celibe/nubile'"
"2" = "Coniugato'"
"3" = "Separato di fatto"
"4" = "Separato legalmente"
"5" = "Divorziato"
"6" = "Vedovo"
;
VALUE $reg7F /* reg */
"010" = "Piemonte"
"020" = "Valle d'Aosta/Vallee' d'Aoste"
"030" = "Lombardia"
"040" = "Trentino A.Adige/Sudtirol"
"050" = "Veneto"
"060" = "Friuli-Venezia Giulia"
"070" = "Liguria"
"080" = "Emilia-Romagna"
"090" = "Toscana"
"100" = "Umbria"
"110" = "Marche"
"120" = "Lazio"
"130" = "Abruzzo"
"140" = "Molise"
"150" = "Campania"
"160" = "Puglia"
"170" = "Basilicata"
"180" = "Calabria"
"190" = "Sicilia"
"200" = "Sardegna"
;
VALUE $rip8F /* rip */
"1" = "Nord-ovest"
"2" = "Nord-est"
"3" = "Centro"
"4" = "Sud"
"5" = "Isole"
;
VALUE $ist9F /* istr */
"01" = "Nessun titolo"
"02" = "Licenza elementare"
"03" = "Licenza media (licenza di avviamento professionale"
"04" = "Dipl. di qualif prof di scuola second di II grado di 2-3 anni,che non permette iscriz univ"
"05" = "Dipl. di istr second sup che permette accesso universita"
"06" = "Dipl. di Accademia (Belle Arti,arte drammatica,Danza),Ist Sup Industrie Artistiche,Conserv di musica,Ist Musicale Pareggiato-vecchio ord.to"
"07" = "Dipl. universitario di due/tre anni, Scuola diretta a fini speciali,altro diploma terziario non universitario"
"08" = "Laurea di I livello - nuovo ordinamento (3 anni)"
"09" = "Laurea - vecchio ordinamento (4/6 anni)"
"10" = "Laurea spec/magistrale a ciclo unico - nuovo ordinamento (corsi di 5/6 anni)"
"11" = "Laurea spec/magistrale - nuovo ordinamento (corsi di II liv di 2 anni)"
"13" = "Dottorato di ricerca/diploma accademico di formazione alla ricerca"
"15" = "Certificato di spec.ne tecnica superiore IFTS"
"16" = "Dipl di tecnico superiore ITS (corsi biennali)"
"17" = "Dipl accad di Alta Formazione Artistica, Musicale e Coreutica (AFAM) di I livello"
"18" = "Dipl accad di Alta Formazione Artistica, Musicale e Coreutica (AFAM) di II livello"
"19" = "Master univ I liv/Dipl accad perfez.to o Master I liv/Diploma accad spec.ne I liv"
"20" = "Master univ II liv/ Dip accad perfez.to o Master di II livello/ Dipl acc spec II livello"
"21" = "Dipl di specializzazione univ"
"22" = "Attestato IeFP di qualifica professionale triennale (operatore,corso trien)/dipl prof IeFP di tecnico(4.to anno)"
;
VALUE $con10F /* condogg */
"01" = "Occupato"
"02" = "In cerca di occupazione"
"03" = "Inattivo"
;
VALUE $pos11F /* posiz */
"01" = "Dirigente"
"02" = "Quadro"
"03" = "Impiegato"
"04" = "Operaio"
"05" = "Apprendista"
"06" = "Lavorante a domicilio per conto d'imprese"
"07" = "Imprenditore"
"08" = "Libero professionista"
"09" = "Lavoratore in proprio"
"10" = "Socio di cooperativa"
"11" = "Coadiuvante nell'azienda di un familiare"
"12" = "Collaboratore coordinato e continuativo (con o senza progetto)"
"13" = "Prestatore d'opera occasionale"
;
VALUE $ate12F /* ateco10 */
"01" = "Agricoltura, caccia e pesca'"
"02" = "Industria'"
"03" = "Costruzioni'"
"04" = "Commercio, trasporto, magazzinaggio, alberghi, ristoranti"
"05" = "Informazione e comunicazione"
"06" = "Attivita' finanziarie"
"07" = "Attivita' immobiliari"
"08" = "Attivita' professionali, scientifiche, attivita' amministrative, servizi di supporto"
"09" = "Pubblica amministrazione, Difesa, Istruzione, Sanita', altri servizi sociali"
"10" = "Altri servizi"
;
VALUE $con13F /* cond */
"01" = "Occupato"
"02" = "In cerca di prima occupazione"
"03" = "In cerca di nuova occupazione"
"04" = "Casalinga"
"05" = "Studente"
"06" = "Persona ritirata dal lavoro"
"07" = "In altra condizione"
;
VALUE $ORA14F /* ORARIO */
"1" = "A tempo pieno"
"2" = "A tempo parziale"
;
VALUE $RAP15F /* RAPP */
"1" = "A tempo determinato"
"2" = "A tempo indeterminato"
;
VALUE $COD16F /* CODPROF */
"1" = "LEGISLATORI, IMPRENDITORI E ALTA DIRIGENZA"
"2" = "PROFESSIONI INTELLETTUALI, SCIENTIFICHE E DI ELEVATA SPECIALIZZAZIONE"
"3" = "PROFESSIONI TECNICHE"
"4" = "PROFESSIONI ESECUTIVE NEL LAVORO D'UFFICIO"
"5" = "PROFESSIONI QUALIFICATE NELLE ATTIVITA' COMMERCIALI E NEI SERVIZI"
"6" = "ARTIGIANI, OPERAI SPECIALIZZATI E AGRICOLTORI"
"7" = "CONDUTTORI DI IMPIANTI, OPERAI DI MACCHINARI FISSI E MOBILI E CONDUCENTI DI VEICOLI"
"8" = "PROFESSIONI NON QUALIFICATE"
"9" = "FORZE ARMATE"
;
VALUE $DES18F /* DEST_EIE */
"1" = "Italia"
"2" = "Estero"
;
VALUE $DES19F /* DEST_ERE */
"001" = "Piemonte"
"002" = "Valle d'Aosta-Vallee' d'Aoste"
"003" = "Lombardia"
"004" = "Trentino-Alto Adige/Sud Tirol"
"005" = "Veneto"
"006" = "Friuli-Venezia Giulia"
"007" = "Liguria"
"008" = "Emilia-Romagna"
"009" = "Toscana"
"010" = "Umbria"
"011" = "Marche"
"012" = "Lazio"
"013" = "Abruzzo"
"014" = "Molise"
"015" = "Campania"
"016" = "Puglia"
"017" = "Basilicata"
"018" = "Calabria"
"019" = "Sicilia"
"020" = "Sardegna"
"121" = "Austria"
"122" = "Belgio"
"123" = "Danimarca"
"124" = "Finlandia"
"125" = "Francia"
"126" = "Germania"
"127" = "Grecia"
"128" = "Irlanda"
"130" = "Lussemburgo"
"132" = "Olanda"
"133" = "Polonia"
"134" = "Portogallo"
"136" = "Repubblica Ceca"
"137" = "Repubblica Slovacca"
"138" = "Spagna"
"139" = "Svezia"
"142" = "Ungheria"
"159" = "Bulgaria"
"161" = "Cipro"
"163" = "Estonia"
"164" = "Latvia"
"165" = "Lituania"
"166" = "Malta"
"167" = "Romania"
"169" = "Slovenia"
"172" = "Croazia"
"200" = "Paesi non UE (escluso Regno Unito)"
"235" = "Regno Unito (non UE dal 2020)"
"300" = "Nord America"
"400" = "Centro-Sud America"
"500" = "Africa"
"600" = "Asia-Oceania"
;
VALUE $DES20F /* DEST_EPR */
"001" = "Torino"
"002" = "Vercelli"
"003" = "Novara"
"004" = "Cuneo"
"005" = "Asti"
"006" = "Alessandria"
"007" = "Valle d'Aosta/Vallee' d'Aoste"
"008" = "Imperia"
"009" = "Savona"
"010" = "Genova"
"011" = "La Spezia"
"012" = "Varese"
"013" = "Como"
"014" = "Sondrio"
"015" = "Milano"
"016" = "Bergamo"
"017" = "Brescia"
"018" = "Pavia"
"019" = "Cremona"
"020" = "Mantova"
"021" = "Bolzano/Bozen"
"022" = "Trento"
"023" = "Verona"
"024" = "Vicenza"
"025" = "Belluno"
"026" = "Treviso"
"027" = "Venezia"
"028" = "Padova"
"029" = "Rovigo"
"030" = "Udine"
"031" = "Gorizia"
"032" = "Trieste"
"033" = "Piacenza"
"034" = "Parma"
"035" = "Reggio nell'Emilia"
"036" = "Modena"
"037" = "Bologna"
"038" = "Ferrara"
"039" = "Ravenna"
"040" = "Forli'-Cesena"
"041" = "Pesaro e Urbino"
"042" = "Ancona"
"043" = "Macerata"
"044" = "Ascoli Piceno"
"045" = "Massa-Carrara"
"046" = "Lucca"
"047" = "Pistoia"
"048" = "Firenze"
"049" = "Livorno"
"050" = "Pisa"
"051" = "Arezzo"
"052" = "Siena"
"053" = "Grosseto"
"054" = "Perugia"
"055" = "Terni"
"056" = "Viterbo"
"057" = "Rieti"
"058" = "Roma"
"059" = "Latina"
"060" = "Frosinone"
"061" = "Caserta"
"062" = "Benevento"
"063" = "Napoli"
"064" = "Avellino"
"065" = "Salerno"
"066" = "L'Aquila"
"067" = "Teramo"
"068" = "Pescara"
"069" = "Chieti"
"070" = "Campobasso"
"071" = "Foggia"
"072" = "Bari"
"073" = "Taranto"
"074" = "Brindisi"
"075" = "Lecce"
"076" = "Potenza"
"077" = "Matera"
"078" = "Cosenza"
"079" = "Catanzaro"
"080" = "Reggio di Calabria"
"081" = "Trapani"
"082" = "Palermo"
"083" = "Messina"
"084" = "Agrigento"
"085" = "Caltanissetta"
"086" = "Enna"
"087" = "Catania"
"088" = "Ragusa"
"089" = "Siracusa"
"090" = "Sassari"
"091" = "Nuoro"
"092" = "Cagliari"
"093" = "Pordenone"
"094" = "Isernia"
"095" = "Oristano"
"096" = "Biella"
"097" = "Lecco"
"098" = "Lodi"
"099" = "Rimini"
"100" = "Prato"
"101" = "Crotone"
"102" = "Vibo Valentia"
"103" = "Verbano-Cusio-Ossola"
"104" = "Olbia-Tempio"
"105" = "Ogliastra"
"106" = "Medio Campidano"
"107" = "Carbonia-Iglesias"
"108" = "Monza e della Brianza"
"109" = "Fermo"
"110" = "Barletta-Andria-Trani"
"111" = "Sud Sardegna"
"999" = "Non sa"
;
VALUE $MOT21F /* MOTESC */
"01" = "Piacere, svago, vacanza"
"02" = "Visita a parenti e/o amici"
"03" = "Motivo religioso, pellegrinaggio"
"04" = "Cultura"
"05" = "Trattamento di salute, cura termale/Visite e cure mediche"
"06" = "Shopping"
"07" = "Motivi di lavoro"
"08" = "Accompagnare un familiare/parente/amico"
"09" = "Bellezze naturali"
"10" = "Gastronomia, folklore o spettacoli"
"11" = "Altro motivo, Non sa/Non risponde"
;
VALUE $PAR22F /* PARTESC */
"1" = "si"
"2" = "no"
;
VALUE $NPA23F /* NPARTESC */
"01" = "1"
"02" = "2"
"03" = "3"
"04" = "4"
"05" = "5 e piu' partecipanti"
;
VALUE $EME24F /* EMEZZO */
"01" = "Aereo"
"02" = "Treno"
"03" = "Nave, battello, motoscafo"
"04" = "Auto a noleggio"
"05" = "Auto propria, di parenti/amici"
"06" = "Pullman turistico"
"07" = "Pullman di linea"
"08" = "Camper, autocaravan"
"09" = "Moto, Motoscooter"
"10" = "Altro"
"11" = "Altro a motore"
;
VALUE $TRI27F /* TRIM */
"01" = "Gennaio-Marzo"
"02" = "Aprile-Giugno"
"03" = "Luglio-Settembre"
"04" = "Ottobre-Dicembre"
;
VALUE $DOM28F /* DOMINIO */
"1" = "Comuni centro dell'area metropolitana"
"2" = "Comuni periferia dell'area metropolitana e comuni con 50.001 ab. e piu'"
"3" = "Altri comuni fino a 50.000 ab."
;
format tr $tr0F.;
format sesso $ses4F.;
format eta5 $eta5F.;
format staciv $sta6F.;
format reg $reg7F.;
format rip $rip8F.;
format istr $ist9F.;
format condogg $con10F.;
format posiz $pos11F.;
format ateco10 $ate12F.;
format cond $con13F.;
format ORARIO $ORA14F.;
format RAPP $RAP15F.;
format CODPROF $COD16F.;
format DEST_EIE $DES18F.;
format DEST_ERE $DES19F.;
format DEST_EPR $DES20F.;
format MOTESC $MOT21F.;
format PARTESC $PAR22F.;
format NPARTESC $NPA23F.;
format EMEZZO $EME24F.;
format TRIM $TRI27F.;
format DOMINIO $DOM28F.;
RUN;
